@@ -65,7 +65,7 @@ class Creature:
             self.matrices = mat
         else:
             self.matrices = []
-            for i in range(hl_count):
+            for i in range(hl_count + 1):
                 self.matrices.append(np.empty([layer_node_counts[i+1], layer_node_counts[i]]))
             for matrix in self.matrices:
                 matrix = randomize(matrix)
@@ -74,4 +74,4 @@ class Creature:
         hidden = input[:]
         for matrix in self.matrices:
             hidden = sig(np.matmul(matrix, hidden))
-        return hidden
\ No newline at end of file
+        return hidden
